@@ -9,7 +9,7 @@ SPc - build-time system path configuration
 use warnings;
 use strict;
 
-our $VERSION = '0.11_01';
+our $VERSION = '0.09';
 
 use File::Spec;
 
@@ -31,8 +31,6 @@ sub _path_types {qw(
 
 =head1 PATHS
 
-See L<Sys::Path/PATHS for details>
-
 =head2 prefix
 
 =head2 localstatedir
@@ -59,6 +57,9 @@ See L<Sys::Path/PATHS for details>
 
 /var/lib
 
+The directory for installing modifiable architecture-independent data.
+http://www.pathname.com/fhs/pub/fhs-2.3.html#VARLIBVARIABLESTATEINFORMATION
+
 =head2 webdir
 
 /var/www
